package main

import (
	"fmt"
	"os"
	"os/signal"
	"syscall"

	"Moonshark/core"
	"Moonshark/core/utils/logger"
)

func main() {
	logger.InitGlobalLogger(logger.LevelDebug, true, false)
	logger.Server("Moonshark is starting to prowl 🦈")

	server, err := core.NewMoonshark("config.lua")
	if err != nil {
		logger.Fatal("Failed to initialize server: %v", err)
	}

	if err := server.Start(); err != nil {
		logger.Fatal("Failed to start server: %v", err)
	}

	stop := make(chan os.Signal, 1)
	signal.Notify(stop, os.Interrupt, syscall.SIGTERM)
	<-stop

	fmt.Print("\n")
	logger.Server("Shutdown signal received")

	if err := server.Shutdown(); err != nil {
		logger.Error("Error during shutdown: %v", err)
		os.Exit(1)
	}
}
